Create dictionary from DHS .MAP codebook
parse_map(map, all_lower = TRUE)A data frame containing metadata, principally variable labels and a vector of value labels.
Currently hardcoded for 111 char width .MAP files, which covers the vast majority of DHS Phase V, VI, and VIII. To be extended in the future and perhaps add other useful options.
mrdt_zip <- tempfile()
download.file("https://dhsprogram.com/data/model_data/dhs/zzmr61fl.zip",
mrdt_zip, mode="wb")
map <- rdhs::read_zipdata(mrdt_zip, "\\.MAP", readLines)
dct <- rdhs:::parse_map(map)